#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const commander_1 = require("commander");
const runner_1 = __importDefault(require("./runner"));
chalk_1.default.level = 3;
commander_1.program
    .arguments("<directory>")
    .description("Analyze the specified directory")
    .option("-f, --framework <framework>", "Specify the framework")
    .option("-e, --extensions <extensions...>", "Specify the extensions", (value, previous) => previous.concat(value), [])
    .option("-exc, --exclude <exclude...>", "Specify the exclude", (value, previous) => previous.concat(value), [])
    .option("--checkFileNames [checkFileNames]", "Check file names", parseBoolean)
    .option("--checkFileContent [checkFileContent]", "Check directories", parseBoolean)
    .option("-w --writeJsonOutput [writeJsonOutput]", "Write json output", parseBoolean)
    .action((directory, options) => {
    var _a, _b, _c;
    if (options.checkFileNames === false &&
        options.checkFileContent === false) {
        return console.error(chalk_1.default.red(`\nError: You must specify ${chalk_1.default.yellow("true")} at least one of the following options: ${chalk_1.default.yellow("--checkFileNames")}, ${chalk_1.default.yellow("--checkFileContent")}\n`));
    }
    if ((_a = options === null || options === void 0 ? void 0 : options.extensions) === null || _a === void 0 ? void 0 : _a.find((d) => !d.includes("."))) {
        return console.error(chalk_1.default.red("\nError: Extensions must include a dot (.)\n"));
    }
    (0, runner_1.default)({
        ...options,
        directory,
        checkFileContent: (_b = options.checkFileContent) !== null && _b !== void 0 ? _b : true,
        checkFileNames: (_c = options.checkFileNames) !== null && _c !== void 0 ? _c : true,
    });
});
commander_1.program.parse(process.argv);
function parseBoolean(value) {
    if (typeof value === "undefined") {
        return undefined;
    }
    return value.toLowerCase() === "true";
}
