"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.logOutput = void 0;
const fs = __importStar(require("fs"));
const cli_table3_1 = __importDefault(require("cli-table3"));
const chalk_1 = __importDefault(require("chalk"));
const logOutput = ({ fileCount, output, fileNameCases, options, }) => {
    // Create an object to store the result information
    const resultObject = {
        date: new Date().toISOString(),
        fileCount,
        fileNameCases,
        options,
        output,
        // ... other result information ...
    };
    // Convert the object to a JSON string
    const resultJson = JSON.stringify(resultObject, null, 2); // The third parameter (2) adds indentation for better readability
    // Log the JSON output to the console
    console.log(chalk_1.default.bold("------------- Result -------------\n"));
    // console.log(resultJson);
    if (options.writeJsonOutput) {
        // Create the directory if it doesn't exist
        const directoryPath = `${options.directory}/.analyze-codebase`;
        if (!fs.existsSync(directoryPath))
            fs.mkdirSync(directoryPath, { recursive: true });
    }
    // Write the JSON output to a file (optional)
    // Continue with your existing console logs (if needed)
    if (fileCount === 0) {
        console.log(chalk_1.default.red(`No files found in ${chalk_1.default.cyan(options.directory)} with extensions ${chalk_1.default.cyan(options.extensions)}\n`));
    }
    else {
        if (options.checkFileNames) {
            console.log(chalk_1.default.bold("File Name Summary:\n"));
            const fileNameTable = new cli_table3_1.default({
                head: [
                    chalk_1.default.bold("File Name Case"),
                    chalk_1.default.bold("Count"),
                    chalk_1.default.bold("Percentage"),
                ],
                colWidths: [30, 10, 15],
            });
            Object.entries(fileNameCases).forEach(([key, value]) => {
                const percentage = ((value / fileCount) * 100).toFixed(2);
                fileNameTable.push([key, value.toString(), `${percentage}%`]);
            });
            console.log(fileNameTable.toString());
            console.log("\n");
        }
        if (options.checkFileContent) {
            console.log(chalk_1.default.bold("Content Type Summary:\n"));
            const contentTypeTable = new cli_table3_1.default({
                head: [
                    chalk_1.default.bold("Content Type"),
                    chalk_1.default.bold("Count"),
                    chalk_1.default.bold("Percentage"),
                ],
                colWidths: [30, 10, 15],
            });
            Object.entries(output).forEach(([key, value]) => {
                const percentage = ((value / output.Physical) * 100).toFixed(2);
                contentTypeTable.push([key, value.toString(), `${percentage}%`]);
            });
            console.log(contentTypeTable.toString());
        }
    }
    if (options.writeJsonOutput) {
        const writePath = `${options.directory}/.analyze-codebase/${resultObject.date}.json`;
        fs.writeFileSync(writePath, resultJson, {
            flag: "w",
        });
        console.log(chalk_1.default.bold(`\nJSON output written to: ${chalk_1.default.cyan(writePath)}\n`));
    }
    console.log(chalk_1.default.bold("\n----------------------------"));
    console.log(chalk_1.default.bold(`\nNumber of files read: ${chalk_1.default.yellow(fileCount)}\n`));
};
exports.logOutput = logOutput;
